embassy-stm32

Crates

git

Versions

stm32l071kz

Flavors

Packing

Enum Packing 

pub enum Packing {
    ZeroExtendOrLeftTruncate,
    Pack,
}
DMA Packing options

Variants



ZeroExtendOrLeftTruncate

If destination is wider: source data is transferred as right aligned, padded with 0s up to the destination data width If source is wider: source data is transferred as right aligned, left-truncated down to the destination data width



Pack

source data is FIFO queued and packed/unpacked at the destination data width, to be transferred in a left (LSB) to right (MSB) order (named little endian) to the destination